## GitSaw
[![PyPI version shields.io](https://img.shields.io/pypi/v/gitsaw.svg)](https://pypi.python.org/pypi/gitsaw/)

Gitsaw will saw off the branches of local git repositories.
Making it easy to clean up if you find yourself with many branches.
